@@ -11,6 +11,8 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-libkleo.h>
+
 #include "keyapprovaldialog.h"
 
 #include "keyrequester.h"
@@ -18,59 +20,75 @@
 #include <KLocalizedString>
 #include <KSeparator>
 
+#include <QGpgME/Protocol>
+
 #include <QApplication>
 #include <QComboBox>
-#include <QDesktopWidget>
 #include <QDialogButtonBox>
 #include <QGridLayout>
 #include <QLabel>
 #include <QPushButton>
+#include <QScreen>
 #include <QScrollArea>
 #include <QStringList>
 #include <QVBoxLayout>
+#include <QWindow>
 
 #include <gpgme++/key.h>
-#include <qgpgme/protocol.h>
 
 static Kleo::EncryptionPreference cb2pref(int i)
 {
     switch (i) {
     default:
-    case 0: return Kleo::UnknownPreference;
-    case 1: return Kleo::NeverEncrypt;
-    case 2: return Kleo::AlwaysEncrypt;
-    case 3: return Kleo::AlwaysEncryptIfPossible;
-    case 4: return Kleo::AlwaysAskForEncryption;
-    case 5: return Kleo::AskWheneverPossible;
+    case 0:
+        return Kleo::UnknownPreference;
+    case 1:
+        return Kleo::NeverEncrypt;
+    case 2:
+        return Kleo::AlwaysEncrypt;
+    case 3:
+        return Kleo::AlwaysEncryptIfPossible;
+    case 4:
+        return Kleo::AlwaysAskForEncryption;
+    case 5:
+        return Kleo::AskWheneverPossible;
     }
 }
 
 static int pref2cb(Kleo::EncryptionPreference p)
 {
     switch (p) {
-    default:                            return 0;
-    case Kleo::NeverEncrypt:            return 1;
-    case Kleo::AlwaysEncrypt:           return 2;
-    case Kleo::AlwaysEncryptIfPossible: return 3;
-    case Kleo::AlwaysAskForEncryption:  return 4;
-    case Kleo::AskWheneverPossible:     return 5;
+    default:
+        return 0;
+    case Kleo::NeverEncrypt:
+        return 1;
+    case Kleo::AlwaysEncrypt:
+        return 2;
+    case Kleo::AlwaysEncryptIfPossible:
+        return 3;
+    case Kleo::AlwaysAskForEncryption:
+        return 4;
+    case Kleo::AskWheneverPossible:
+        return 5;
     }
 }
 
 static QStringList preferencesStrings()
 {
-    return QStringList() << xi18n("<placeholder>none</placeholder>")
-           << i18n("Never Encrypt with This Key")
-           << i18n("Always Encrypt with This Key")
-           << i18n("Encrypt Whenever Encryption is Possible")
-           << i18n("Always Ask")
-           << i18n("Ask Whenever Encryption is Possible");
+    return QStringList() << xi18n("<placeholder>none</placeholder>") //
+                         << i18n("Never Encrypt with This Key") //
+                         << i18n("Always Encrypt with This Key") //
+                         << i18n("Encrypt Whenever Encryption is Possible") //
+                         << i18n("Always Ask") //
+                         << i18n("Ask Whenever Encryption is Possible");
 }
 
-class Q_DECL_HIDDEN Kleo::KeyApprovalDialog::Private
+class Q_DECL_HIDDEN Kleo::KeyApprovalDialog::KeyApprovalDialogPrivate
 {
 public:
-    Private() {}
+    KeyApprovalDialogPrivate()
+    {
+    }
 
     Kleo::KeyRequester *selfRequester = nullptr;
     QStringList addresses;
@@ -79,11 +97,9 @@ public:
     bool prefsChanged = false;
 };
 
-Kleo::KeyApprovalDialog::KeyApprovalDialog(const std::vector<Item> &recipients,
-        const std::vector<GpgME::Key> &sender,
-        QWidget *parent)
-    : QDialog(parent),
-      d(new Private())
+Kleo::KeyApprovalDialog::KeyApprovalDialog(const std::vector<Item> &recipients, const std::vector<GpgME::Key> &sender, QWidget *parent)
+    : QDialog(parent)
+    , d(new KeyApprovalDialogPrivate())
 {
     setWindowTitle(i18nc("@title:window", "Encryption Key Approval"));
     auto mainLayout = new QVBoxLayout(this);
@@ -147,22 +163,18 @@ Kleo::KeyApprovalDialog::KeyApprovalDialog(const std::vector<Item> &recipients,
         cb->addItems(prefs);
         glay->addWidget(cb, row, 1);
         cb->setCurrentIndex(pref2cb(it->pref));
-        connect(cb, QOverload<int>::of(&QComboBox::activated), this, &KeyApprovalDialog::slotPrefsChanged);
+        connect(cb, qOverload<int>(&QComboBox::activated), this, &KeyApprovalDialog::slotPrefsChanged);
         d->preferences.push_back(cb);
     }
 
     QSize size = sizeHint();
 
     // don't make the dialog too large
-    const QRect desk = QApplication::desktop()->screenGeometry(this);
-    resize(QSize(qMin(size.width(), 3 * desk.width() / 4),
-                 qMin(size.height(), 7 * desk.height() / 8)));
+    const QSize desk = screen()->size();
+    resize(QSize(qMin(size.width(), 3 * desk.width() / 4), qMin(size.height(), 7 * desk.height() / 8)));
 }
 
-Kleo::KeyApprovalDialog::~KeyApprovalDialog()
-{
-    delete d;
-}
+Kleo::KeyApprovalDialog::~KeyApprovalDialog() = default;
 
 std::vector<GpgME::Key> Kleo::KeyApprovalDialog::senderKeys() const
 {
@@ -194,4 +206,3 @@ void Kleo::KeyApprovalDialog::slotPrefsChanged()
 {
     d->prefsChanged = true;
 }
-
